@@ -16,8 +16,6 @@
   +----------------------------------------------------------------------+
 */
 
-/* $Id$ */
-
 #ifndef PHP_PDO_DRIVER_H
 #define PHP_PDO_DRIVER_H
 
@@ -435,7 +433,7 @@ enum pdo_placeholder_support {
 
 struct _pdo_dbh_t {
 	/* driver specific methods */
-	struct pdo_dbh_methods *methods;
+	const struct pdo_dbh_methods *methods;
 	/* driver specific data */
 	void *driver_data;
 
@@ -563,7 +561,7 @@ struct pdo_bound_param_data {
 /* represents a prepared statement */
 struct _pdo_stmt_t {
 	/* driver specifics */
-	struct pdo_stmt_methods *methods;
+	const struct pdo_stmt_methods *methods;
 	void *driver_data;
 
 	/* if true, we've already successfully executed this statement at least
@@ -661,9 +659,9 @@ struct _pdo_row_t {
 };
 
 /* call this in MINIT to register your PDO driver */
-PDO_API int php_pdo_register_driver(pdo_driver_t *driver);
+PDO_API int php_pdo_register_driver(const pdo_driver_t *driver);
 /* call this in MSHUTDOWN to unregister your PDO driver */
-PDO_API void php_pdo_unregister_driver(pdo_driver_t *driver);
+PDO_API void php_pdo_unregister_driver(const pdo_driver_t *driver);
 
 /* For the convenience of drivers, this function will parse a data source
  * string, of the form "name=value; name2=value2" and populate variables
@@ -693,6 +691,7 @@ PDO_API void php_pdo_dbh_delref(pdo_dbh_t *dbh);
 PDO_API void php_pdo_free_statement(pdo_stmt_t *stmt);
 
 
+PDO_API void pdo_throw_exception(unsigned int driver_errcode, char *driver_errmsg, pdo_error_type *pdo_error);
 #endif /* PHP_PDO_DRIVER_H */
 /*
  * Local variables:
